@@ -91,9 +91,12 @@ cheese_gconf_get_property (GObject *object, guint prop_id, GValue *value,
           }
         }
         if (effects == NULL)
-          effects = str;
-        else
+          effects = g_strdup (str);
+        else {
+          gchar *dummy = effects;
           effects = g_strjoin (",", effects, str, NULL);
+          g_free (dummy);
+        }
 
         g_free (tmp->data);
         tmp = g_slist_next (tmp);
