@@ -47,6 +47,8 @@ G_DEFINE_TYPE (CheeseWebcam, cheese_webcam, G_TYPE_OBJECT)
 
 #define CHEESE_WEBCAM_ERROR cheese_webcam_error_quark ()
 
+#define MIN_DEFAULT_RATE 15.0
+
 static void find_highest_framerate (CheeseVideoFormat *format);
 
 enum CheeseWebcamError
@@ -159,6 +161,10 @@ cheese_webcam_set_x_overlay (CheeseWebcam *webcam)
   GstXOverlay *overlay = GST_X_OVERLAY (gst_bin_get_by_interface (GST_BIN (priv->pipeline),
                                                                   GST_TYPE_X_OVERLAY));
 
+  if (g_object_class_find_property (G_OBJECT_GET_CLASS (overlay),
+                                    "force-aspect-ratio"))
+    g_object_set (G_OBJECT (overlay), "force-aspect-ratio", TRUE, NULL);
+
   gst_x_overlay_set_xwindow_id (overlay, GDK_WINDOW_XWINDOW (priv->video_window->window));
 }
 
@@ -185,7 +191,12 @@ cheese_webcam_change_sink (CheeseWebcam *webcam, GstElement *src,
 static gboolean
 cheese_webcam_expose_cb (GtkWidget *widget, GdkEventExpose *event, CheeseWebcam *webcam)
 {
-  cheese_webcam_set_x_overlay (webcam);
+  CheeseWebcamPrivate *priv = CHEESE_WEBCAM_GET_PRIVATE (webcam);
+
+  GstXOverlay *overlay = GST_X_OVERLAY (gst_bin_get_by_interface (GST_BIN (priv->pipeline),
+                                                                  GST_TYPE_X_OVERLAY));
+
+  gst_x_overlay_expose (overlay);
   return FALSE;
 }
 
@@ -826,11 +837,14 @@ cheese_webcam_create_webcam_source_bin (CheeseWebcam *webcam)
                                 CheeseVideoFormat, 0));
       for (i = 1; i < selected_webcam->num_video_formats; i++)
       {
-        if (g_array_index (selected_webcam->video_formats,
-                           CheeseVideoFormat, i).width > format->width)
+        CheeseVideoFormat *new = &g_array_index (selected_webcam->video_formats,
+                                                 CheeseVideoFormat, i);
+        gfloat newrate = new->highest_framerate.numerator /
+          new->highest_framerate.denominator;
+        if ((new->width+new->height) > (format->width+format->height) &&
+            (newrate >= MIN_DEFAULT_RATE))
         {
-          format = &(g_array_index (selected_webcam->video_formats,
-                                    CheeseVideoFormat, i));
+          format = new;
         }
       }
     }
@@ -1120,7 +1134,12 @@ cheese_webcam_create_video_save_bin (CheeseWebcam *webcam, GError **error)
   if ((mux = gst_element_factory_make ("oggmux", "mux")) == NULL)
   {
     cheese_webcam_set_error_element_not_found (error, "oggmux");
+  } else {
+    g_object_set (G_OBJECT (mux),
+                  "max-delay", (guint64) 10000000,
+                  "max-page-delay", (guint64) 10000000, NULL);
   }
+
   if ((priv->video_file_sink = gst_element_factory_make ("filesink", "video_file_sink")) == NULL)
   {
     cheese_webcam_set_error_element_not_found (error, "filesink");
